{% extends "planet/base.html" %}
{% load i18n pagination_tags  %}

{% block head_title %}{% trans "Tags cloud" %}{% endblock %}

{% block extra_head %}
    <meta name="title" content="{% trans 'Tags cloud' %} - {{ site.name }}" />
    <meta name="description" content="{% trans 'Tags cloud' %} - {{ site.name }}" />
    <meta name="robots" content="noindex, follow" />
{% endblock %}

{% block breadcrumb_section %}<li class="active">Tags</li>{% endblock %}

{% block content %}
<h1>{% trans "Tags cloud" %}</h1>
<div class="tags cloud">
    {% autopaginate tags_cloud 200 %}
    {% for tag in tags_cloud %}
        <a href="{% url 'planet_tag_detail' tag.name %}" class="level{{ tag.font_size }}">{{ tag }}</a>
    {% endfor %}
    {% paginate %}
</div>
{% endblock %}
