{% extends "planet/base.html" %}
{% load i18n pagination_tags planet_tags %}

{% block head_title %}{% trans 'Post list' %}{{ block.super }}{% endblock %}

{% block extra_head %}
    <meta name="title" content="{% trans 'Post list' %} - {{ site.name }}" />
    <meta name="description" content="{% trans 'Posts list' %} - {{ site.name }}" />
    <meta name="robots" content="noindex, follow" />
{% endblock %}

{% block breadcrumb_section %}<li class="active">{% trans 'Posts' %}</li>{% endblock %}

{% block content %}
    <h1>{% trans "Latest posts" %}</h1>
    {% autopaginate posts 10 %}
    {% for post in posts %}
        <div class="post">
            {% post_details post %}
        </div>
    {% endfor %}

    {% paginate %}
{% endblock %}

