.cloud .level1 { font-size: 0.9em; }
.cloud .level2 { font-size: 1em; }
.cloud .level3 { font-size: 1.1em; }
.cloud .level4 { font-size: 1.2em; }
.cloud .level5 { font-size: 1.3em; }
.cloud .level6 { font-size: 1.4em; }
.cloud .level7 { font-size: 1.5em; }
body { background: url("images/wavegrid.png") repeat scroll 0 0 transparent; }
