{% extends "planet/base.html" %}
{% load i18n planet_tags %}

{% block head_title %}{{ post.title|safe }}{% endblock %}

{% block extra_head %}
    <meta name="title" content="{{ post.title|safe }} - {{ site.name }}" />
    <meta name="description" content="{% get_first_paragraph post.content as description %}{{ description }}" />
    <meta name="robots" content="index, follow" />
    <link rel="canonical" href="http://{{ site.domain }}{{ post.get_absolute_url }}"/>
{% endblock %}

{% block breadcrumb_section %}
    <li><a href="{% url 'planet.views.blogs_list' %}">Blogs</a> <span class="divider">/</span></li>
    <li><a href="{{ post.feed.blog.get_absolute_url }}">{{ post.feed.blog.title }}</a> <span class="divider">/</span></li>
    <li><a href="{{ post.feed.get_absolute_url }}">{{ post.feed.title }}</a> <span class="divider">/</span></li>
{% endblock %}
{% block breadcrumb_detail %}<li class="active">{{ post.title|safe }}</li>{% endblock %}

{% block content %}
    <div class="post clearfix">
        {% post_full_details post %}
        <div class="content">
            {{ post.content|safe|clean_html }}
        </div>
    </div>
{% endblock %}

{% block right_column %}
    {% cloud_for_feed post.feed %}
    {% include 'planet/feeds/blocks/syndication_block.html' %}
{% endblock %}
