{% load i18n %}
{% if tags_cloud %}
<h4>{% trans "Tag cloud" %}</h3>
<div class="tags cloud">
    {% for tag in tags_cloud %}
        <a href="{% url 'planet_by_tag_feed_detail' feed.id feed.get_slug tag.name %}" class="tag level{{ tag.font_size }}">{{ tag }}</a>
    {% endfor %}
</div>
{% endif %}
