{% extends "planet/base.html" %}
{% load i18n pagination_tags planet_tags  %}

{% block head_title %}{% trans "List of tags and categories" %}{% endblock %}

{% block extra_head %}
    <meta name="title" content="{% trans 'Tags list' %} - {{ site.name }}" />
    <meta name="description" content="{% trans 'Tags list' %} - {{ site.name }}" />
    <meta name="robots" content="noindex, follow" />
{% endblock %}

{% block content %}
<h1>{% trans "Tags" %}</h1>
<div class="tags list">
    {% autopaginate tags_list 50 %}
    <ul>
    {% for tag in tags_list %}
        <li><a href="{% url 'planet_tag_detail' tag.name %}" class="tag">{{ tag }}</a></li>
    {% endfor %}
    </ul>
    {% paginate %}
</div>
{% endblock %}
